searchData={"content_type":"text/markdown","items":[{"doc":"Documentation for `Shogun`.","ref":"Shogun.html","title":"Shogun","type":"module"},{"doc":"Wrapper that uses gun websocket client","ref":"Shogun.Websocket.html","title":"Shogun.Websocket","type":"behaviour"},{"doc":"```elixir\ndefmodule MyWebsocket do\n  use Shogun.Websocket\nend\n\n{:ok, pid} = MyWebsocket.start_link(url: \"ws://localhost/websocket\")\n```","ref":"Shogun.Websocket.html#module-usage","title":"Usage - Shogun.Websocket","type":"behaviour"},{"doc":"```elixir\ndefmodule MyWebsocket do\n  use Shogun.Websocket\n\n  @impl Shogun.Websocket\n  def on_connect(_headers, state, _opts) do\n    # Doing something awesome ...\n    state\n  end\nend\n```","ref":"Shogun.Websocket.html#module-usage-of-callbacks","title":"Usage of callbacks - Shogun.Websocket","type":"behaviour"},{"doc":"**url:** url to websocket server (ws or wss), for instance `ws://websocket_server/`. **required**\n\n**connect_timeout:** Connection timeout. default :infinity\n\n**cookie_store:** The cookie store that Gun will use for this connection. When configured, Gun will query the store for cookies and include them in the request headers; and add cookies found in response headers to the store.\n\n  By default no cookie store will be used.\n\n**domain_lookup_timeout:** Domain lookup timeout. default :infinity\n\n**http_opts:** Options specific to the HTTP protocol.\n\n**retry:** Number of times Gun will try to reconnect on failure before giving up.\n\n**retry_fun:** A fun that will be called before every reconnect attempt. It receives the current number of retries left and the Gun options. It returns the next number of retries left and the timeout to apply before reconnecting.\n\nThe default fun will remove one to the number of retries and set the timeout to the retry_timeout value.\n\nThe fun must be defined as follow:\n\n```elixir\nfn(non_neg_integer(), opts()) -> %{\n  retries => non_neg_integer(),\n  timeout => pos_integer()\n} end\n```\n\nThe fun will never be called when the retry option is set to 0. When this function returns 0 in the retries value, Gun will do one last reconnect attempt before giving up.\n\n**retry_timeout:** Time between retries in milliseconds. default 5000\n\n**supervise:** Whether the Gun process should be started under the gun_sup supervisor. Set to false to use your own supervisor. default true\n\n**tcp_opts:** TCP options used when establishing the connection. By default Gun enables send timeouts with the options [{send_timeout, 15000}, {send_timeout_close, true}].\n\n**tls_handshake_timeout:** TLS handshake timeout. default :infinity\n\n**tls_opts:** TLS options used for the TLS handshake after the connection has been established, when the transport is set to tls. default []\n\n**trace:** Whether to enable dbg tracing of the connection process. Should only be used during debugging. default false\n\n**transport:** Whether to use TLS or plain TCP. The default varies depending on the port used. Port 443 defaults to tls. All other ports default to tcp.\n\n**ws_opts:** Options specific to the Websocket protocol.\n\n**internal_state:** Initial internal state that could be updated when messages are comming.\n\n**internal_opts:** opts that could be used each time a message is comming.\n\nPlease visit https://ninenines.eu/docs/en/gun/2.0/manual/gun/ for more info about the opts","ref":"Shogun.Websocket.html#module-opts","title":"Opts - Shogun.Websocket","type":"behaviour"},{"doc":"trigger when the websocket client fails to connect successfully","ref":"Shogun.Websocket.html#c:on_close/3","title":"Shogun.Websocket.on_close/3","type":"callback"},{"doc":"trigger when the websocket client connects successfully","ref":"Shogun.Websocket.html#c:on_connect/3","title":"Shogun.Websocket.on_connect/3","type":"callback"},{"doc":"trigger when the connection is lost (gun will try to connect again and upgrade to ws)","ref":"Shogun.Websocket.html#c:on_disconnect/3","title":"Shogun.Websocket.on_disconnect/3","type":"callback"},{"doc":"trigger when the websocket client has abruptly an error","ref":"Shogun.Websocket.html#c:on_error/3","title":"Shogun.Websocket.on_error/3","type":"callback"},{"doc":"trigger when the websocket client recieves an message from the server","ref":"Shogun.Websocket.html#c:on_message/3","title":"Shogun.Websocket.on_message/3","type":"callback"},{"doc":"","ref":"Shogun.Websocket.html#t:code/0","title":"Shogun.Websocket.code/0","type":"type"},{"doc":"","ref":"Shogun.Websocket.html#t:headers/0","title":"Shogun.Websocket.headers/0","type":"type"},{"doc":"","ref":"Shogun.Websocket.html#t:message/0","title":"Shogun.Websocket.message/0","type":"type"},{"doc":"","ref":"Shogun.Websocket.html#t:reason/0","title":"Shogun.Websocket.reason/0","type":"type"},{"doc":"","ref":"Shogun.Websocket.html#t:state/0","title":"Shogun.Websocket.state/0","type":"type"},{"doc":"","ref":"Shogun.Websocket.Client.html","title":"Shogun.Websocket.Client","type":"behaviour"},{"doc":"Only intented to be used inside the `websocket.ex` file after init","ref":"Shogun.Websocket.Client.html#c:connect/1","title":"Shogun.Websocket.Client.connect/1","type":"callback"},{"doc":"","ref":"Shogun.Websocket.Client.html#t:state/0","title":"Shogun.Websocket.Client.state/0","type":"type"},{"doc":"","ref":"Shogun.Websocket.Gun.html","title":"Shogun.Websocket.Gun","type":"module"},{"doc":"GunTest can help to test your implementation of Shogun.Websocket\nFollow the steps to test it out\n\nFirst step:\n\nset the client for the websocket in `config/test.exs`\n\n```elixir\nconfig :shogun, Shogun.Websocket,\n  client: Shogun.Websocket.GunTest\n```\n\nSecond step:\n\nnow on your test, you can control the messages that your websocket received.\n\n```elixir\ndefmodule MyApp.WebsocketTest do\n  use ExUnit.Case, async: true\n\n  alias Shogun.Websocket.GunTest\n\n  setup _context do\n    {:ok, ws_pid} = start_supervised({MyApp.Websocket, url: \"test\"})\n    [ws_pid: ws_pid]\n  end\n\n  test \"validate message test is received by the client\", %{ws_pid: ws_pid} do\n    GunTest.receive_message(ws_pid, \"test\")\n    assert :sys.get_state(ws_pid).internal_state.message == \"test\"\n  end\nend\n\n```","ref":"Shogun.Websocket.GunTest.html","title":"Shogun.Websocket.GunTest","type":"module"},{"doc":"","ref":"Shogun.Websocket.GunTest.html#receive_message/2","title":"Shogun.Websocket.GunTest.receive_message/2","type":"function"}]}